summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmquickcoloredit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmquickcoloredit.h')
-rw-r--r--kpovmodeler/pmquickcoloredit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmquickcoloredit.h b/kpovmodeler/pmquickcoloredit.h
index 456b9660..f3e6d9df 100644
--- a/kpovmodeler/pmquickcoloredit.h
+++ b/kpovmodeler/pmquickcoloredit.h
@@ -41,9 +41,9 @@ class PMQuickColorEdit : public PMDialogEditBase
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMQuickColorEdit with tqparent and name
*/
- PMQuickColorEdit( TQWidget* tqparent, const char* name = 0 );
+ PMQuickColorEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -41,9 +41,9 @@ class PMQuickColorEdit : public PMDialogEditBase
public:
/**
- * Creates a PMQuickColorEdit with tqparent and name
+ * Creates a PMQuickColorEdit with parent and name
*/